pub struct StructuredEmbedder { /* private fields */ }Expand description
Structured embedder that converts payloads to vectors based on schema
Implementations
Sourceimpl StructuredEmbedder
impl StructuredEmbedder
Sourcepub fn new(schema: SimilaritySchema) -> Self
pub fn new(schema: SimilaritySchema) -> Self
Create a new structured embedder with the given schema
Sourcepub fn with_dimensions(
schema: SimilaritySchema,
text_dim: usize,
categorical_dim: usize,
) -> Self
pub fn with_dimensions( schema: SimilaritySchema, text_dim: usize, categorical_dim: usize, ) -> Self
Create embedder with custom dimensions
Sourcepub fn vector_dim(&self) -> usize
pub fn vector_dim(&self) -> usize
Get the total vector dimension for this embedder
Sourcepub fn schema(&self) -> &SimilaritySchema
pub fn schema(&self) -> &SimilaritySchema
Get a reference to the schema